==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/fr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "activated" : "activé",
    "updated" : "mis à jour",
    "mounted" : "Monté",
    "deactivated" : "désactivé",
    "beforeCreate" : "Avant la création",
    "created" : "créé",
    "beforeUpdate" : "Avant la mise à jour",
    "beforeDestroy" : "Avant la suppresion",
    "destroyed" : "détruit",
    "beforeMount" : "Avant montage",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Voici vos codes de récupération. Veuillez les sauvegarder et/ou les imprimer car vous ne pourrez plus y avoir accès ultérieurement",
    "Save backup codes" : "Sauvegarder les codes de récupération",
    "Print backup codes" : "Imprimer les codes de récupération",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Les codes de récupération ont été générés. {used} codes sur {total} ont été utilisés.",
    "Regenerate backup codes" : "Régénérer les codes de récupération",
    "_icon-loading-small_::_generate-backup-codes_" : ["petie-icone-de-chargement","generer-code-de-secours"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si vous régénérez les codes de récupération, vous invalidez automatiquement les anciens codes.",
    "Generate backup codes" : "Générer des codes de récupération",
    "An error occurred while generating your backup codes" : "Une erreur est survenue lors de la génération de vos codes de récupération",
    "Nextcloud backup codes" : "Codes de récupération Nextcloud",
    "You created two-factor backup codes for your account" : "Vous avez créé des codes de secours à deux facteurs pour votre compte",
    "Second-factor backup codes" : "Codes de récupération pour l'authentification en deux étapes",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Vous avez activé l'authentification en deux étapes mais vous n'avez pas généré de code de secours. Soyez sûr de le faire au cas où vous perdriez l'accès à votre moyen de connexion.",
    "Backup code" : "Code de récupération",
    "Use backup code" : "Utiliser un code de récupération",
    "Two factor backup codes" : "Code de secours pour l'authentification double facteur.",
    "A two-factor auth backup codes provider" : "Un fournisseur de codes de récupération d'authentification à deux facteurs",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Utilisez l'un des codes de secours que vous avez crée lors du paramétrage de l'authentification à deux facteurs.",
    "Submit" : "Envoyer",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Les codes de récupération ont été générés. {{used}} codes sur {{total}} ont été utilisés."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/fr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Une erreur est survenue lors de la génération de vos codes de récupération",
    "Nextcloud backup codes" : "Codes de récupération Nextcloud",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Voici vos codes de récupération. Veuillez les sauvegarder et/ou les imprimer car vous ne pourrez plus y avoir accès ultérieurement",
    "Save backup codes" : "Sauvegarder les codes de récupération",
    "Print backup codes" : "Imprimer les codes de récupération",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Les codes de récupération ont été générés. {used} codes sur {total} ont été utilisés.",
    "Regenerate backup codes" : "Régénérer les codes de récupération",
    "_icon-loading-small_::_generate-backup-codes_" : ["petie-icone-de-chargement","generer-code-de-secours"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si vous régénérez les codes de récupération, vous invalidez automatiquement les anciens codes.",
    "Generate backup codes" : "Générer des codes de récupération",
    "You created two-factor backup codes for your account" : "Vous avez créé des codes de secours à deux facteurs pour votre compte",
    "Second-factor backup codes" : "Codes de récupération pour l'authentification en deux étapes",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Vous avez activé l'authentification en deux étapes mais vous n'avez pas généré de code de secours. Soyez sûr de le faire au cas où vous perdriez l'accès à votre moyen de connexion.",
    "Backup code" : "Code de récupération",
    "Use backup code" : "Utiliser un code de récupération",
    "Two factor backup codes" : "Code de secours pour l'authentification double facteur.",
    "A two-factor auth backup codes provider" : "Un fournisseur de codes de récupération d'authentification à deux facteurs",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Utilisez l'un des codes de secours que vous avez crée lors du paramétrage de l'authentification à deux facteurs.",
    "Submit" : "Envoyer",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Les codes de récupération ont été générés. {{used}} codes sur {{total}} ont été utilisés.",
    "activated" : "activé",
    "updated" : "mis à jour",
    "mounted" : "Monté",
    "deactivated" : "désactivé",
    "beforeCreate" : "Avant la création",
    "created" : "créé",
    "beforeUpdate" : "Avant la mise à jour",
    "beforeDestroy" : "Avant la suppresion",
    "destroyed" : "détruit",
    "beforeMount" : "Avant montage"
},
"nplurals=2; plural=(n > 1);");
